import uuid
from typing import Annotated

from fastapi import APIRouter, Body, Path

from app.api.dependencies import SessionDep
from app.crud.user_crud import create_user
from app.database.models.user_model import UserRole
from app.schemas.user_schemas import UserRegister

router = APIRouter(
    prefix="/user"
)


@router.delete("/delete", summary="Delete user")
async def delete_user(shop_uuid=Annotated[uuid.UUID, Path(title="UUID of the shop")]):
    raise NotImplementedError("delete_user() needs to be implemented.")


@router.delete("/logout", summary="User logout")
async def logout():
    raise NotImplementedError("logout() needs to be implemented.")


@router.post("/register", summary="Register new user")
async def register(session: SessionDep, user_data: UserRegister, shop_uuid=Annotated[uuid.UUID, Path(title="UUID of the shop")]):
    create_user(session, user_data, shop_uuid, UserRole.CUSTOMER)


@router.put("/update", summary="Update user details")
async def update_user(data: dict = Body(...)):
    raise NotImplementedError("update_user() needs to be implemented.")
